@@ -1,3 +1,9 @@
+asCharacter <- function(...) {
+  res <- as.character(...)
+  if (length(res) == 0) "" # happens when '{{ null }}'
+  else res
+}
+
 addAttr <- function(x, ...) {
   newAttr <- list(...)
   for (n in names(newAttr)) {
